"use strict";
// *******************************************************************************
//  * Copyright 2023 Adobe
//  *
//  * Licensed under the Apache License, Version 2.0 (the “License”);
//  * you may not use this file except in compliance with the License.
//  * You may obtain a copy of the License at
//  *
//  *     http://www.apache.org/licenses/LICENSE-2.0
//  *
//  * Unless required by applicable law or agreed to in writing, software
//  * distributed under the License is distributed on an “AS IS” BASIS,
//  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//  * See the License for the specific language governing permissions and
//  * limitations under the License.
//  ******************************************************************************
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.withRuleEnginePanel = exports.withRuleEngine = exports.richTextString = void 0;
const react_1 = __importDefault(require("react"));
const af_core_1 = require("@aemforms/af-core");
const af_react_renderer_1 = require("@aemforms/af-react-renderer");
const sanitize_html_1 = __importDefault(require("sanitize-html"));
const DEFAULT_ERROR_MESSAGE = 'There is an error in the field';
const richTextString = (stringMsg = '') => {
    const htmlProp = { __html: (0, sanitize_html_1.default)(stringMsg) };
    return (react_1.default.createElement("span", { dangerouslySetInnerHTML: htmlProp }));
};
exports.richTextString = richTextString;
const formateErrorMessage = (state) => {
    const errorMessage = state.errorMessage === '' && state.valid === false ? DEFAULT_ERROR_MESSAGE : state.errorMessage;
    return errorMessage;
};
const getValidationState = (state) => {
    const optionalValidation = !(0, af_core_1.checkIfConstraintsArePresent)(state) && state.type === 'string';
    const validationState = state.valid === false ? 'invalid' : ((state.valid === undefined || (0, af_core_1.isEmpty)(state.value) || optionalValidation) ? undefined : 'valid');
    return validationState;
};
const getLocalizeLabel = (i18n, state, richText) => {
    const labelId = (0, af_core_1.getOrElse)(state, ['properties', 'afs:translationIds', 'label.value']);
    const label = labelId ? i18n.formatMessage({ id: labelId, defaultMessage: state?.label?.value }) : state?.label?.value;
    return richText ? (0, exports.richTextString)(label) : label;
};
const getLocalizeDescription = (i18n, state) => {
    const descriptionId = (0, af_core_1.getOrElse)(state, ['properties', 'afs:translationIds', 'description']);
    const description = descriptionId ? i18n.formatMessage({ id: descriptionId, defaultMessage: state?.description }) : state?.description;
    return description ? (0, exports.richTextString)(description) : null;
};
const getLocalizePlaceholder = (i18n, state) => {
    const placeholderId = (0, af_core_1.getOrElse)(state, ['properties', 'afs:translationIds', 'placeholder']);
    const placeholder = placeholderId ? i18n.formatMessage({ id: placeholderId, defaultMessage: state?.placeholder }) : state?.placeholder;
    return placeholder;
};
const getLocalizeEnumNames = (i18n, state) => {
    const enumNames = state?.enumNames || [];
    return enumNames.map((item, index) => {
        const EnumName = typeof item === 'object' ? item.value : item;
        const localizeEnumId = (0, af_core_1.getOrElse)(state, ['properties', 'afs:translationIds', 'enumNames']);
        const localizeEnumName = localizeEnumId ? i18n.formatMessage({ id: `localizeEnumId##${index}`, defaultMessage: EnumName }) : EnumName;
        return typeof item === 'object' && item?.richText ? (0, exports.richTextString)(localizeEnumName) : localizeEnumName;
    });
};
const getToolTip = (state) => {
    const tooltipVisible = state.properties?.['afs:layout']?.tooltipVisible;
    return tooltipVisible && state.tooltip ? (0, exports.richTextString)(state.tooltip) : null;
};
function withRuleEngine(Component) {
    return function WrappedComponent(fieldset) {
        const [state, handlers] = (0, af_react_renderer_1.useRuleEngine)(fieldset);
        const i18n = (0, af_react_renderer_1.useFormIntl)();
        const localizeState = {
            ...state,
            description: getLocalizeDescription(i18n, state),
            placeholder: getLocalizePlaceholder(i18n, state),
            tooltip: getToolTip(state),
            label: {
                ...state?.label,
                value: getLocalizeLabel(i18n, state, state?.label?.richText),
                visible: state.label?.visible !== false
            },
            isError: getValidationState(state) === 'invalid',
            errorMessage: formateErrorMessage(state),
            layout: {
                orientation: 'horizontal',
                ...((0, af_core_1.getOrElse)(state, ['properties', 'afs:layout'], {}))
            },
            enumNames: getLocalizeEnumNames(i18n, state)
        };
        const visible = typeof state.visible === 'undefined' || state.visible;
        // @ts-ignore
        return visible ? react_1.default.createElement(Component, { ...localizeState, ...handlers }) : null;
    };
}
exports.withRuleEngine = withRuleEngine;
function withRuleEnginePanel(Component) {
    return function WrappedComponent(fieldset) {
        const [state, handlers] = (0, af_react_renderer_1.useRuleEngine)(fieldset);
        const i18n = (0, af_react_renderer_1.useFormIntl)();
        const localizeState = {
            ...state,
            label: {
                ...state?.label,
                value: getLocalizeLabel(i18n, state, state?.label?.richText),
                visible: state.label?.visible !== false
            },
            description: getLocalizeDescription(i18n, state),
            tooltip: getToolTip(state)
        };
        const visible = typeof state.visible === 'undefined' || state.visible;
        // @ts-ignore
        return visible ? react_1.default.createElement(Component, { ...localizeState, handlers: handlers }) : null;
    };
}
exports.withRuleEnginePanel = withRuleEnginePanel;
